==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/java/org/gnu/gdk/Cursor.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.glib.Boxed;
import org.gnu.javagnome.Handle;

public class Cursor extends Boxed {

    protected Cursor( Handle hndl ) {
        super( hndl );
    }

    /**
     *	Creates a new cursor from the set of builtin cursors.
     */
    public Cursor(CursorType ctype) {
        super(gdk_cursor_new(ctype.getValue()));
    }

    /**
     * Create a new cursor from a pixmap.
     */
    public Cursor(Pixmap source, Pixmap mask, 
                  Color fg, Color bg, 
                  int x, int y) {
        super(gdk_cursor_new_from_pixmap(source.getHandle(), mask.getHandle(),
                                         fg.getHandle(), bg.getHandle(), 
                                         x, y));
    }

    /**
     * Package private helper method.
     */
    static Cursor getCursorFromHandle( Handle hndl ) {
        if ( hndl != null ) {
            Boxed box = Boxed.getBoxedFromHandle( hndl );
            return ( box != null ) ? (Cursor)box : new Cursor(hndl);
        }
        return null;
    }

    native static final protected int getType(Handle obj);
    native static final protected Handle gdk_cursor_new(int cursorType);
    native static final protected Handle gdk_cursor_new_from_pixmap(Handle source, Handle mask, Handle fg, Handle bg, int x, int y);
}

==> libgtk-java-2.8.1.tar.bz2: libgtk-java-2.8.1/src/java/org/gnu/gdk/Cursor.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.glib.Boxed;
import org.gnu.glib.Handle;

public class Cursor extends Boxed {

    protected Cursor( Handle hndl ) {
        super( hndl );
    }

    /**
     *	Creates a new cursor from the set of builtin cursors.
     */
    public Cursor(CursorType ctype) {
        super(gdk_cursor_new(ctype.getValue()));
    }

    /**
     * Create a new cursor from a pixmap.
     */
    public Cursor(Pixmap source, Pixmap mask, 
                  Color fg, Color bg, 
                  int x, int y) {
        super(gdk_cursor_new_from_pixmap(source.getHandle(), mask.getHandle(),
                                         fg.getHandle(), bg.getHandle(), 
                                         x, y));
    }

    /**
     * Package private helper method.
     */
    static Cursor getCursorFromHandle( Handle hndl ) {
        if ( hndl != null ) {
            Boxed box = Boxed.getBoxedFromHandle( hndl );
            return ( box != null ) ? (Cursor)box : new Cursor(hndl);
        }
        return null;
    }

    native static final protected int getType(Handle obj);
    native static final protected Handle gdk_cursor_new(int cursorType);
    native static final protected Handle gdk_cursor_new_from_pixmap(Handle source, Handle mask, Handle fg, Handle bg, int x, int y);
}
